From mboxrd@z Thu Jan 1 00:00:00 1970 Return-Path: Received: (majordomo@vger.kernel.org) by vger.kernel.org via listexpand id S1755612AbbESLp0 (ORCPT ); Tue, 19 May 2015 07:45:26 -0400 Received: from smtp-out6.electric.net ([192.162.217.185]:63436 "EHLO smtp-out6.electric.net" rhost-flags-OK-OK-OK-OK) by vger.kernel.org with ESMTP id S1755467AbbESLpV (ORCPT ); Tue, 19 May 2015 07:45:21 -0400 From: David Laight To: "'Christophe Leroy'" , Benjamin Herrenschmidt , Paul Mackerras , "Michael Ellerman" , "scottwood@freescale.com" CC: "linuxppc-dev@lists.ozlabs.org" , "linux-kernel@vger.kernel.org" Subject: RE: [PATCH v2 0/6] powerpc32: replace memcpy and memset by cacheable alternatives Thread-Topic: [PATCH v2 0/6] powerpc32: replace memcpy and memset by cacheable alternatives Thread-Index: AQHQkhuFW3fkhAXsdUKMSqPNDwGBr52DLBFw Date: Tue, 19 May 2015 11:43:13 +0000 Message-ID: <063D6719AE5E284EB5DD2968C1650D6D1CB39783@AcuExch.aculab.com> References: In-Reply-To: Accept-Language: en-GB, en-US Content-Language: en-US X-MS-Has-Attach: X-MS-TNEF-Correlator: x-originating-ip: [10.202.99.200] Content-Type: text/plain; charset="utf-8" MIME-Version: 1.0 X-Outbound-IP: 213.249.233.130 X-Env-From: David.Laight@ACULAB.COM X-PolicySMART: 3396946, 3397078 Sender: linux-kernel-owner@vger.kernel.org List-ID: X-Mailing-List: linux-kernel@vger.kernel.org Content-Transfer-Encoding: 8bit X-MIME-Autoconverted: from base64 to 8bit by nfs id t4JBjVYl001186 From: Christophe Leroy > Sent: 19 May 2015 11:08 > > This patchset implements use of cacheable versions of memset and > memcpy since when the destination is not cacheable, memset_io > and memcpy_toio are used. This isn't the right list to ask, but: Can someone fix the x86 versions of memset/memcpy (and the _io variants) so that they don't end up being 'rep movsb' on new intel cpus? I've a C2558 Atom which has the optimised 'rep movsb' hardware. Copies to/from uncached locations are now done 'byte by byte'. As well as kernel code this affects userpace copying to/from mmap()ed PCIe space. 64bit reads are slow enough, making it 8 times slower is horrid. I suspect this affect some network drivers as well. David ÿôèº{.nÇ+‰·Ÿ®‰­†+%ŠËÿ±éݶ¥Šwÿº{.nÇ+‰·¥Š{±þG«�éÿŠ{ayºʇڙë,j­¢f£¢·hš�ï�êÿ‘êçz_è®(­éšŽŠÝ¢j"�ú¶m§ÿÿ¾«þG«�éÿ¢¸?™¨è­Ú&£ø§~�á¶iO•æ¬z·švØ^¶m§ÿÿà ÿ¶ìÿ¢¸?–I¥